@@ -2,11 +2,11 @@
 import typing as t
 
 
-__version__ = "0.2.0"
+__version__ = "1.0.0"
 
 PickInstruction = t.Dict[str, t.Union[int, bool]]
 DiceInstruction = t.Dict[str, int]
-RollInstruction = t.Tuple[PickInstruction, DiceInstruction, int]
+RollInstruction = t.Tuple[DiceInstruction, PickInstruction, int]
 
 
 QUANTITY_GROUP: int = 1
@@ -23,7 +23,7 @@ MODIFIER: str = "modifier"
 ROLLS: str = "rolls"
 QUOTA: str = "quota"
 BEST: str = "best"
-PICK_DEFAULT: int = {BEST: True, QUOTA: 0}
+PICK_DEFAULT: dict = {BEST: True, QUOTA: 0}
 PICKS: str = "picks"
 BEST: str = "best"
 VALUE: str = "value"
